export declare const kPatterns: [RegExp, string | Replacer][];

/**
 * Replaces CSS patterns in strings using regular expressions and predefined patterns.
 * @param {string[] | string} entry - The CSS string or an array of CSS strings to be processed.
 * @param {[RegExp, string | Replacer][]} patterns - Optional. Custom replacement patterns. Default is predefined patterns.
 * @returns {string} The processed CSS string.
 * @example
 *```typescript
 *console.log(
 *  `div { ${marco([
 *    'transition-colors',
 *    'transition-none',
 *    'blur-md',
 *    'drop-shadow-xl',
 *  ])} }`
 *);
 *```
 *Will generate the following CSS string:
 *
 *```css
 *div {
 *  transition-property: color, background-color, border-color,
 *    text-decoration-color, fill, stroke;
 *  transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);
 *  transition-duration: 150ms;
 *  transition-property: none;
 *  filter: blur(12px);
 *  filter: drop-shadow(0 20px 13px rgb(0 0 0 / 0.03)) drop-shadow(
 *      0 8px 5px rgb(0 0 0 / 0.08)
 *    );
 *}
 *```
 */
export declare function marco(entry: string[] | string, patterns?: [RegExp, string | Replacer][]): string;

declare type Replacer = (match: string, ...args: string[]) => string;

export { }
